Module resource

Module resource 

Resource trait — the thing a capability grants access to.

Structs

GenericResource
A generic, string-keyed resource for use in tests and the CLI simulator.

Traits

Resource
A resource that can be protected by a Capability.